# -*- coding: utf-8 -*-

from django.db import models
from django.utils.translation import ugettext_lazy as _

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel


class Vat(DateModel, UserModel, StatusModel, OrderedModel):
    """
    Stores vats: value added tax
    """
    code = models.CharField(
        primary_key=True,
        max_length=15,
        verbose_name=_('code'),
    )
    name = models.CharField(
        unique=True,
        max_length=100,
        verbose_name=_('name'),
    )
    slug = models.SlugField(
        db_index=True,
        max_length=200,
        verbose_name=_("slug"),
        help_text=_("used for URLs, auto-generated from name if blank"),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_('description'),
    )
    aliquot_perc = models.DecimalField(
        max_digits=4,
        decimal_places=2,
        default=0,
        verbose_name=_("aliquot perc"),
    )
    deduct_perc = models.DecimalField(
        max_digits=4,
        decimal_places=2,
        default=0,
        verbose_name=_("deduct perc"),
    )

    class Meta:
        verbose_name = _('VAT rate')
        verbose_name_plural = _('VAT rates')
        ordering = ('ordering', 'name')

    def __unicode__(self):
        return u"{}".format(self.name)
